@@ -10,13 +10,11 @@ class Archive:public File
   private:
     bool IsSignature(byte *D);
     void UpdateLatestTime(FileHeader *CurBlock);
-    void Protect(int RecSectors);
     void ConvertNameCase(char *Name);
     void ConvertNameCase(wchar *Name);
     void ConvertUnknownHeader();
-    bool AddArcComment(char *NameToShow);
-    int ReadOldHeader();
-    void PrepareExtraTime(FileHeader *hd,EXTTIME_MODE etm,EXTTIME_MODE etc,EXTTIME_MODE eta,EXTTIME_MODE etarc,Array<byte> &TimeData);
+    size_t ReadOldHeader();
+    void UnexpEndArcMsg();
 
 #if !defined(SHELL_EXT) && !defined(NOCRYPT)
     CryptData HeadersCrypt;
@@ -32,7 +30,9 @@ class Archive:public File
     OldMainHeader OldMhd;
 
     int RecoverySectors;
-    Int64 RecoveryPos;
+    int64 RecoveryPos;
+
+    bool FailedHeaderDecryption;
 
     RarTime LatestTime;
     int LastReadBlock;
@@ -42,27 +42,17 @@ class Archive:public File
   public:
     Archive(RAROptions *InitCmd=NULL);
     bool IsArchive(bool EnableBroken);
-    int SearchBlock(int BlockType);
-    int SearchSubBlock(const char *Type);
+    size_t SearchBlock(int BlockType);
+    size_t SearchSubBlock(const char *Type);
     int ReadBlock(int BlockType);
     void WriteBlock(int BlockType,BaseBlock *wb=NULL);
     int PrepareNamesToWrite(char *Name,wchar *NameW,char *DestName,byte *DestNameW);
     void SetLhdSize();
-    int ReadHeader();
+    size_t ReadHeader();
     void CheckArc(bool EnableBroken);
-    void CheckOpen(char *Name,wchar *NameW=NULL);
-    bool WCheckOpen(char *Name,wchar *NameW=NULL);
-    bool TestLock(int Mode);
-    void MakeTemp();
-    void CopyMainHeader(Archive &Src,bool CopySFX=true,char *NameToDisplay=NULL);
-    bool ProcessToFileHead(Archive &Src,bool LastBlockAdded,
-      Pack *Pack=NULL,const char *SkipName=NULL);
-    void TmpToArc(Archive &Src);
-    void CloseNew(int AdjustRecovery,bool CloseVolume);
-    void WriteEndBlock(bool CloseVolume);
-    void CopyFileRecord(Archive &Src);
-    void CopyArchiveData(Archive &Src);
-    bool GetComment(Array<byte> &CmtData);
+    void CheckOpen(const char *Name,const wchar *NameW=NULL);
+    bool WCheckOpen(const char *Name,const wchar *NameW=NULL);
+    bool GetComment(Array<byte> *CmtData,Array<wchar> *CmtDataW);
     void ViewComment();
     void ViewFileComment();
     void SetLatestTime(RarTime *NewTime);
@@ -71,15 +61,13 @@ class Archive:public File
     bool IsArcDir();
     bool IsArcLabel();
     void ConvertAttributes();
-    int LhdSize();
-    int LhdExtraSize();
     int GetRecoverySize(bool Required);
-    void VolSubtractHeaderSize(int SubSize);
-    void AddSubData(byte *SrcData,int DataSize,File *SrcFile,char *Name,bool AllowSplit);
+    void VolSubtractHeaderSize(size_t SubSize);
+    void AddSubData(byte *SrcData,size_t DataSize,File *SrcFile,const char *Name,bool AllowSplit);
     bool ReadSubData(Array<byte> *UnpData,File *DestFile);
     int GetHeaderType() {return(CurHeaderType);};
-    int ReadCommentData(Array<byte> &CmtData);
-    void WriteCommentData(byte *Data,int DataSize,bool FileComment);
+    size_t ReadCommentData(Array<byte> *CmtData,Array<wchar> *CmtDataW);
+    void WriteCommentData(byte *Data,size_t DataSize,bool FileComment);
     RAROptions* GetRAROptions() {return(Cmd);}
     void SetSilentOpen(bool Mode) {SilentOpen=Mode;}
 
@@ -98,8 +86,8 @@ class Archive:public File
     EAHeader EAHead;
     StreamHeader StreamHead;
 
-    Int64 CurBlockPos;
-    Int64 NextBlockPos;
+    int64 CurBlockPos;
+    int64 NextBlockPos;
 
     bool OldFormat;
     bool Solid;
@@ -110,16 +98,16 @@ class Archive:public File
     bool NotFirstVolume;
     bool Protected;
     bool Encrypted;
-    unsigned int SFXSize;
+    size_t SFXSize;
     bool BrokenFileHeader;
 
     bool Splitting;
 
     ushort HeaderCRC;
 
-    Int64 VolWrite;
-    Int64 AddingFilesSize;
-    uint AddingHeadersSize;
+    int64 VolWrite;
+    int64 AddingFilesSize;
+    size_t AddingHeadersSize;
 
     bool NewArchive;
 
@@ -127,4 +115,5 @@ class Archive:public File
     wchar FirstVolumeNameW[NM];
 };
 
+
 #endif
